# Generated by roxygen2: do not edit by hand

S3method(print,compfit_result)
S3method(print,fit_result)
S3method(print,fullfit_result)
S3method(print,multifit_result)
S3method(print,survtable)
S3method(print,table2docx_result)
S3method(print,table2pptx_result)
S3method(print,table2rtf_result)
S3method(print,uniscreen_result)
export(autoforest)
export(autotable)
export(compfit)
export(coxforest)
export(desctable)
export(fit)
export(fullfit)
export(glmforest)
export(lmforest)
export(m2dt)
export(multifit)
export(multiforest)
export(survtable)
export(table2docx)
export(table2html)
export(table2pdf)
export(table2pptx)
export(table2rtf)
export(table2tex)
export(uniforest)
export(uniscreen)
import(data.table)
importFrom(grDevices,axisTicks)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,IQR)
importFrom(stats,anova)
importFrom(stats,aov)
importFrom(stats,binomial)
importFrom(stats,chisq.test)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,confint)
importFrom(stats,cor)
importFrom(stats,family)
importFrom(stats,fisher.test)
importFrom(stats,fitted)
importFrom(stats,fivenum)
importFrom(stats,formula)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,kruskal.test)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stats,wilcox.test)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,tail)
