#' Global Variables for Package Check
#'
#' This file declares global variables used in non-standard evaluation (NSE)
#' contexts throughout the package, primarily in data.table and ggplot2 operations.
#' These declarations prevent R CMD check warnings about "no visible binding for
#' global variable".
#'
#' @importFrom stats aov fivenum
#' @keywords internal
#' @noRd

.datatable.aware <- TRUE

utils::globalVariables(c(
           
           ## data.table special symbols
           ".",
           "..",
           ".BY",
           ".GRP",
           ".I",
           ".N",
           ".NGRP",
           ".SD",

           ## data.table column selection with .. prefix
           "..available_cols",
           "..cols",
           "..cols_available",
           "..cols_needed",
           "..complete_vars",
           "..display_cols",
           "..keep_cols",
           "..key_cols",
           "..new_order",
           
           ## Column names used in statistical models and summaries
           "Estimate",
           "Events",
           "Freq",
           "Group",
           "HR",
           "Multi p",
           "OR",
           "Predictor",
           "R2",
           "RR",
           "N",
           "Composite Model Score (CMS)",
           "Uni p",
           "Variable",
           "p-value",
           
           ## Variables used in analysis functions
           "CMS",
           ".int_term",
           ".is_ref",
           ".group_order",
           ".multi_n",
           ".multi_Events",
           ".orig_order",
           ".row_in_var",
           ".temp_var_order",
           ".var_group",
           ".var_group_id",
           "age",
           "all_nonempty",
           "breaks",
           "brier",
           "ci_lower",
           "ci_lower_adj",
           "ci_lower_unadj",
           "ci_upper",
           "ci_upper_adj",
           "ci_upper_unadj",
           "c_statistic",
           "clean_level",
           "coef",
           "coef_lower",
           "coef_upper",
           "coefficient",
           "coef_names",
           "conf_high",
           "conf_high_formatted",
           "conf_low",
           "conf_low_formatted",
           "current_term",
           "deviance",
           "display_n",
           "display_events",
           "display_text",
           "effect",
           "effect_col",
           "effect_formatted",
           "effect_label",
           "effect_string_expr",
           "estimate",
           "event_data",
           "event_var",
           "events",
           "events_calc",
           "events_formatted",
           "events_group",
           "exp_coef",
           "exp_coef_adj",
           "exp_coef_unadj",
           "exp_lower",
           "exp_upper",
           "group",
           "group_var",
           "groups",
           "grp",
           "grp_data",
           "grp_denom",
           "hr",
           "hr_formatted",
           "hr_string_expr",
           "i..orig_order",
           "inds",
           "i.var_new",
           "i.events_group",
           "i.n_group",
           "i.Freq",
           "integrated_loglik",
           "is_continuous",
           "is_header",
           "is_reference",
           "label",
           "level",
           "level_display",
           "level_order",
           "level_row",
           "level_term",
           "matching",
           "multi_effect",
           "multi_p",
           "n",
           "n_events",
           "n_obs",
           "null_deviance",
           "n_formatted",
           "n_group",
           "n_miss",
           "orig_level",
           "orig_var",
           "outcome",
           "outcome_var",
           "p_adj",
           "p_formatted",
           "p_unadj",
           "p_value",
           "parent_var",
           "pos",
           "predictor",
           "pval",
           "ref_level",
           "reference",
           "reference_label",
           "result",
           "row_type",
           "rows",
           "rows_to_delete",
           "se",
           "sex",
           "shade_group",
           "should_bold",
           "sigma",
           "sort_key",
           "stage",
           "statistic",
           "status_var",
           "term",
           "theta",
           "time_var",
           "tjur_r2",
           "treatment",
           "uni_effect",
           "uni_p",
           "using",
           "var",
           "var_display",
           "var_new",
           "var_order",
           "var_orig",
           "var_rows",
           "variable",
           "variables",
           "x_pos",
           ".events_calc",

           ## ggplot2 aesthetics and coordinate variables
           "x",
           "y",
           "xend",
           "xmax",
           "xmin",
           "yend",
           "ymax",
           "ymin"
       ))
