% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comp_utils.R
\name{normalize_model_type}
\alias{normalize_model_type}
\title{Normalize model type names}
\usage{
normalize_model_type(model_type)
}
\arguments{
\item{model_type}{Character string of model type or class name.}
}
\value{
Normalized character string (\emph{e.g.,} "lmerMod" becomes "lmer").
}
\description{
Converts model class names to standardized model type strings.
}
\keyword{internal}
