% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/multifit.R
\name{format_multifit_table}
\alias{format_multifit_table}
\title{Format multifit results for publication}
\usage{
format_multifit_table(
  data,
  columns,
  show_n = TRUE,
  show_events = TRUE,
  digits = 2,
  p_digits = 3,
  labels = NULL,
  predictor_label = NULL,
  include_predictor = TRUE,
  exponentiate = NULL,
  conf_level = 0.95,
  marks = NULL
)
}
\arguments{
\item{data}{Raw combined data.table from combine_multifit_results.}

\item{columns}{Character specifying column layout.}

\item{show_n}{Logical for sample size column.}

\item{show_events}{Logical for events column.}

\item{digits}{Integer decimal places for effects.}

\item{p_digits}{Integer decimal places for p-values.}

\item{labels}{Named vector of labels for outcomes and predictors.}

\item{predictor_label}{Label for predictor variable.}

\item{include_predictor}{Logical for including predictor column.}

\item{exponentiate}{Logical or \code{NULL} for coefficient handling.}
}
\value{
Formatted data.table.
}
\description{
Internal helper that formats raw multivariate results into 
publication-ready table format.
}
\keyword{internal}
