% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/m2dt_utils.R
\name{get_model_type_name}
\alias{get_model_type_name}
\title{Get readable model type name}
\usage{
get_model_type_name(model)
}
\arguments{
\item{model}{Fitted model object.}
}
\value{
Character string with readable model type name.
}
\description{
Converts model class names to human-readable descriptions. For GLMs,
uses the family to provide specific names (\emph{e.g.,} "Logistic", "Poisson").
}
\keyword{internal}
