% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table2docx.R
\name{print.table2docx_result}
\alias{print.table2docx_result}
\title{Print method for table2docx results}
\usage{
\method{print}{table2docx_result}(x, ...)
}
\arguments{
\item{x}{Object of class \code{table2docx_result}.}

\item{...}{Additional arguments passed to print methods.}
}
\value{
Invisibly returns the input object \code{x}. Called for its
  side effect of printing a formatted summary to the console.
}
\description{
Print method for table2docx results
}
\keyword{internal}
