% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table2_utils.R
\name{format_column_headers_html}
\alias{format_column_headers_html}
\title{Apply formatting to column headers in exported tables (HTML)}
\usage{
format_column_headers_html(col_names)
}
\arguments{
\item{col_names}{Character vector of column names.}
}
\value{
Character vector with HTML-formatted column names.
}
\description{
Formats column headers for HTML output by italicizing 'n' and 'p'
using HTML tags.
}
\keyword{internal}
