% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comp_utils.R
\name{format_model_comparison}
\alias{format_model_comparison}
\title{Format model comparison table}
\usage{
format_model_comparison(comparison)
}
\arguments{
\item{comparison}{Data.table with comparison metrics.}
}
\value{
Data.table with properly rounded numeric columns.
}
\description{
Rounds numeric columns to appropriate precision based on metric type.
}
\keyword{internal}
