% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/multifit.R
\name{format_pvalues_multifit}
\alias{format_pvalues_multifit}
\title{Format p-values for multifit display}
\usage{
format_pvalues_multifit(p, digits = 3, marks = NULL)
}
\arguments{
\item{p}{Numeric vector of p-values.}

\item{digits}{Integer number of decimal places. Also determines the threshold
for "less than" display: threshold = 10^(-digits). Default is 3.}

\item{marks}{Optional list with \code{big.mark} and \code{decimal.mark} as
returned by \code{\link{resolve_number_marks}}.}
}
\value{
Character vector of formatted p-values.
}
\description{
Converts numeric p-values to formatted character strings. Values below the 
threshold (determined by digits parameter) display as "< 0.001" (for digits=3),
"< 0.0001" (for digits=4), \emph{etc.} NA values display as "-".
}
\keyword{internal}
