% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/desc_utils.R
\name{get_stat_label}
\alias{get_stat_label}
\title{Get display label for statistic type}
\usage{
get_stat_label(stat_type)
}
\arguments{
\item{stat_type}{Character string: "mean_sd", "median_iqr", "median_range",
"range", "n_miss", or custom type.}
}
\value{
Character string with formatted label (\emph{e.g.,} "Mean \eqn{\pm} SD").
}
\description{
Converts internal statistic type codes to formatted display labels for
table column headers.
}
\keyword{internal}
