% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/multifit.R
\name{validate_outcome_homogeneity}
\alias{validate_outcome_homogeneity}
\title{Validate outcome homogeneity for multifit}
\usage{
validate_outcome_homogeneity(data, outcomes, model_type, family = "binomial")
}
\arguments{
\item{data}{Data.table containing the analysis data.}

\item{outcomes}{Character vector of outcome variable names.}

\item{model_type}{Character string specifying the model type.}

\item{family}{Character string specifying the GLM family (for glm/glmer).}
}
\value{
Invisible \code{NULL}. Issues warnings if problems are detected.
}
\description{
Checks whether all outcomes in a multifit analysis are compatible with the
specified model type. Issues a warning when outcomes appear to be of mixed
types (\emph{e.g.,} binary and continuous outcomes in the same analysis), which
would produce tables with incompatible effect measures.
}
\keyword{internal}
