% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table2_utils.R
\name{format_headers_ft}
\alias{format_headers_ft}
\title{Format headers for flextable}
\usage{
format_headers_ft(ft, has_n_row, n_row_data)
}
\arguments{
\item{ft}{\pkg{flextable} object.}

\item{has_n_row}{Logical whether source data had an N row.}

\item{n_row_data}{Data from the N row for adding counts to headers.}
}
\value{
Formatted \pkg{flextable} object.
}
\description{
Applies formatting to flextable headers including italicizing 'n',
adding sample size counts from N row data, and bolding all headers.
}
\keyword{internal}
