% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comp_utils.R
\name{extract_glmer_metrics}
\alias{extract_glmer_metrics}
\title{Extract metrics for generalized linear mixed-effects models (glmer)}
\usage{
extract_glmer_metrics(model, raw_data, metrics)
}
\arguments{
\item{model}{Fitted glmerMod object from lme4.}

\item{raw_data}{Data.table with raw model information.}

\item{metrics}{Named list of initialized metrics to populate.}
}
\value{
Updated metrics list with glmer-specific values.
}
\description{
Extracts quality metrics specific to generalized linear mixed-effects models
including concordance, R-squared measures, ICC, and Brier score for binomial.
}
\keyword{internal}
