% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/forest_utils.R
\name{convert_units}
\alias{convert_units}
\title{Convert between units}
\usage{
convert_units(value, from = "in", to = "in", dpi = 96)
}
\arguments{
\item{value}{Numeric value to convert.}

\item{from}{Character string specifying source unit ("in", "cm", "mm", "px", "pt").}

\item{to}{Character string specifying target unit ("in", "cm", "mm", "px", "pt").}

\item{dpi}{Integer dots per inch for pixel conversions (default 96).}
}
\value{
Numeric value in target units.
}
\description{
Converts measurements between different unit systems commonly used in
graphics (inches, centimeters, millimeters, pixels, points).
}
\keyword{internal}
