% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comp_utils.R
\name{check_convergence}
\alias{check_convergence}
\title{Check model convergence}
\usage{
check_convergence(model)
}
\arguments{
\item{model}{Fitted model object.}
}
\value{
Character string: "Yes", "No", "Suspect", or "Failed"
}
\description{
Checks convergence status for various model types including standard
regression models and mixed-effects models.
}
\keyword{internal}
