% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/comp_utils.R
\name{order_comparison_columns}
\alias{order_comparison_columns}
\title{Order comparison columns based on model type}
\usage{
order_comparison_columns(comparison, model_type)
}
\arguments{
\item{comparison}{Data.table with comparison metrics.}

\item{model_type}{Character string indicating model type.}
}
\value{
Data.table with reordered columns.
}
\description{
Reorders columns in the comparison table to follow a logical sequence
appropriate for the model type.
}
\keyword{internal}
