% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table2_utils.R
\name{determine_alignment}
\alias{determine_alignment}
\title{Determine alignment for exported tables}
\usage{
determine_alignment(df)
}
\arguments{
\item{df}{Data.frame or data.table to determine alignment for.}
}
\value{
Character string with alignment codes (\emph{e.g.,} "rlcc").
}
\description{
Creates column alignment string for LaTeX tables. Variable and Group
columns are left-aligned; all others are centered.
}
\keyword{internal}
